@@ -438,7 +438,7 @@ struct test_unique
 
         int index = 0;
         ::std::for_each(host_first1, host_first1 + n, [&index](Iterator1ValueType& value) { value = (index++ + 4) / 4; });
-        int64_t expected_size = (n - 1) / 4 + 1;
+        std::int64_t expected_size = (n - 1) / 4 + 1;
 
         auto tuple_lastnew =
             ::std::unique(make_new_policy<new_kernel_name<Policy, 0>>(exec), tuple_first1, tuple_last1,
@@ -475,7 +475,7 @@ struct test_unique_copy
         int index = 0;
         ::std::for_each(host_first1, host_first1 + n, [&index](Iterator1ValueType& value) { value = (index++ + 4) / 4; });
         ::std::fill(host_first2, host_first2 + n, Iterator1ValueType{-1});
-        int64_t expected_size = (n - 1) / 4 + 1;
+        std::int64_t expected_size = (n - 1) / 4 + 1;
 
         auto tuple_last2 =
             ::std::unique_copy(make_new_policy<new_kernel_name<Policy, 0>>(exec), tuple_first1, tuple_last1, tuple_first2,
@@ -668,67 +668,67 @@ struct test_counting_zip_transform
 };
 #endif
 
-int32_t
+std::int32_t
 main()
 {
 #if TEST_DPCPP_BACKEND_PRESENT
 #if defined(_PSTL_TEST_FOR_EACH)
     PRINT_DEBUG("test_for_each");
-    test1buffer<int32_t, test_for_each>();
+    test1buffer<std::int32_t, test_for_each>();
 #endif
 #if defined(_PSTL_TEST_FOR_EACH_STRUCTURED_BINDING)
     PRINT_DEBUG("test_for_each_structured_binding");
-    test1buffer<int32_t, test_for_each_structured_binding>();
+    test1buffer<std::int32_t, test_for_each_structured_binding>();
 #endif
 #if defined(_PSTL_TEST_TRANSFORM_REDUCE_UNARY)
     PRINT_DEBUG("test_transform_reduce_unary");
-    test1buffer<int32_t, test_transform_reduce_unary>();
+    test1buffer<std::int32_t, test_transform_reduce_unary>();
 #endif
 #if defined(_PSTL_TEST_TRANSFORM_REDUCE_BINARY)
     PRINT_DEBUG("test_transform_reduce_binary");
-    test2buffers<int32_t, test_transform_reduce_binary>();
+    test2buffers<std::int32_t, test_transform_reduce_binary>();
 #endif
 #if defined(_PSTL_TEST_COUNT_IF)
     PRINT_DEBUG("test_count_if");
-    test1buffer<int32_t, test_count_if>();
+    test1buffer<std::int32_t, test_count_if>();
 #endif
 #if defined(_PSTL_TEST_EQUAL)
     PRINT_DEBUG("test_equal");
-    test2buffers<int32_t, test_equal>();
+    test2buffers<std::int32_t, test_equal>();
 #endif
 #if defined(_PSTL_TEST_EQUAL_STRUCTURED_BINDING)
     PRINT_DEBUG("test_equal_structured_binding");
-    test2buffers<int32_t, test_equal_structured_binding>();
+    test2buffers<std::int32_t, test_equal_structured_binding>();
 #endif
 #if defined(_PSTL_TEST_INCLUSIVE_SCAN)
     PRINT_DEBUG("test_inclusive_scan");
-    test2buffers<int32_t, test_transform_inclusive_scan>();
+    test2buffers<std::int32_t, test_transform_inclusive_scan>();
 #endif
 #if defined(_PSTL_TEST_UNIQUE)
     PRINT_DEBUG("test_unique");
-    test1buffer<int32_t, test_unique>();
+    test1buffer<std::int32_t, test_unique>();
 #endif
 #if defined(_PSTL_TEST_UNIQUE_COPY)
     PRINT_DEBUG("test_unique_copy");
-    test2buffers<int32_t, test_unique_copy>();
+    test2buffers<std::int32_t, test_unique_copy>();
 #endif
 #if defined(_PSTL_TEST_MERGE)
     PRINT_DEBUG("test_merge");
-    test3buffers<int32_t, test_merge>();
+    test3buffers<std::int32_t, test_merge>();
 #endif
 // sorting with zip iterator does not meet limits of RAM usage on FPGA.
 // TODO: try to investigate and reduce RAM consumption
 #if defined(_PSTL_TEST_STABLE_SORT) && !ONEDPL_FPGA_DEVICE
     PRINT_DEBUG("test_stable_sort");
-    test2buffers<int32_t, test_stable_sort>();
+    test2buffers<std::int32_t, test_stable_sort>();
 #endif
 #if defined(_PSTL_TEST_LEXICOGRAPHICAL_COMPIARE)
     PRINT_DEBUG("test_lexicographical_compare");
-    test2buffers<int32_t, test_lexicographical_compare>();
+    test2buffers<std::int32_t, test_lexicographical_compare>();
 #endif
 #if defined(_PSTL_TEST_COUNTING_ZIP_TRANSFORM)
     PRINT_DEBUG("test_counting_zip_transform");
-    test2buffers<int32_t, test_counting_zip_transform>();
+    test2buffers<std::int32_t, test_counting_zip_transform>();
 #endif
 #endif
     return done(TEST_DPCPP_BACKEND_PRESENT);
